@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../../..';
 
@@ -14,22 +14,23 @@ use vars qw(@ISA @SUBCMD_VARS);
 use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
-our $HELP         = <<"HELP";
+our $HELP         = <<'HELP';
+=pod
 
 Evaluate unrecognized debugger commands.
 
 Often inside the debugger, one would like to be able to run arbitrary
-Perl commands without having to preface expressions with \"print\" or
-\"eval\". Setting \"auto eval\" on will cause unrecognized debugger
+Perl commands without having to preface expressions with C<print> or
+C<eval>. Setting C<auto eval> on will cause unrecognized debugger
 commands to be evaluated as a Perl expression. 
 
-If the expression starts with \%, \@, or \$ the context will be set 
+If the expression starts with %, @, or $ the context will be set 
 to a hash, array or scalar accordingly.
 
 Note that if auto eval is set, the message shown on type a bad
 debugger command changes from:
 
-  Undefined command: \"fdafds\". Try \"help\".
+  Undefined command: "fdafds". Try "help".
 
 to something more Perl-specific such as:
 
@@ -42,10 +43,11 @@ as a variable, such as in an assignment statement. For example:
   s /a/b/  # Note the space after the s
 
 is not a Perl substitute command but a "step" command when 'auto eval'
-is on because by default, 's' is an alias for the debugger 'step'
+is on because by default, C<s> is an alias for the debugger C<step>
 command. It is possible to remove that alias if this causes constant
 problem. Another possibility is to go into a real shell via the
-'shell' command.  
+C<shell> command.  
+=cut
 HELP
 
 our $MIN_ABBREV   = length('ev');
