@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# This line is for testing purposes \
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 
 # Module for reading debugger scripts
 
@@ -42,7 +43,7 @@ sub new
     $self->{input_lineno}  = 0;
     $self->{buffer_output} = [];
     unless ($opts->{verbose} or $out) {
-	$self->{output} = Devel::Trepan::IO::StringArrayOutput->new($self->{buffer_output});
+        $self->{output} = Devel::Trepan::IO::StringArrayOutput->new($self->{buffer_output});
     }    
     bless $self, $class;
     $self;
@@ -79,10 +80,10 @@ sub errmsg($$;$)
     my $mess = sprintf "%s%s", $prefix, $msg;
 
     if ($self->{opts}{verbose}) {
-	my $location = sprintf("%s:%s: Error in source command file",
-			       $self->{script_name}, 
-			       $self->{input_lineno});
-	$mess = sprintf("%s:\n%s%s", $prefix, $location, $prefix, $msg);
+        my $location = sprintf("%s:%s: Error in source command file",
+                               $self->{script_name}, 
+                               $self->{input_lineno});
+        $mess = sprintf("%s:\n%s%s", $prefix, $location, $prefix, $msg);
     }
     
     $self->msg($mess);
@@ -96,9 +97,9 @@ sub msg($$)
     my ($self, $msg) = @_;
     ## FIXME: there must be a better way to do this...
     if ($self->{output}->isa('Devel::Trepan::IO::TCPServer')) {
-	$self->{output}->writeline(PRINT . $msg);
+        $self->{output}->writeline(PRINT . $msg);
     } else {
-	$self->{output}->writeline($msg);
+        $self->{output}->writeline($msg);
     }
 }
 
@@ -113,13 +114,20 @@ sub read_command($;$)
     my ($self, $prompt)=@_;
     $prompt = '' unless defined $prompt;
     $self->{input_lineno} += 1;
-    my $line = $self->readline();
+    my $last = $self->readline();
+    my $line = '';
+    while ('\\' eq substr($last, -1)) { 
+        $line .= substr($last, 0, -1) . "\n";
+        $last = $self->readline();
+    }
+    $line .= $last;
+
     if ($self->{opts}{verbose}) {
-	my $location = sprintf("%s line %s",
-			       $self->{script_name}, 
-			       $self->{input_lineno});
-	my $mess = sprintf '+ %s: %s', $location, $line;
-	$self->msg($mess);
+        my $location = sprintf("%s line %s",
+                               $self->{script_name}, 
+                               $self->{input_lineno});
+        my $mess = sprintf '+ %s: %s', $location, $line;
+        $self->msg($mess);
     }
     # Do something with history?
     return $line;
@@ -153,7 +161,7 @@ unless (caller) {
     my $intf = __PACKAGE__->new(__FILE__);
     my $line = $intf->readline();
     print "Line read: ${line}\n";
-    $line = $intf->readline();
+    $line = $intf->read_command();
     print "Second Line read: ${line}\n";
 }
 
